@@ -13,8 +13,13 @@
 # under the License.
 
 import collections
+import six
+
+if six.PY2:
+    from monotonic import monotonic as now
+else:
+    from time import monotonic as now
 
-import monotonic
 from oslo_log import log
 from oslo_utils import timeutils
 
@@ -47,21 +52,21 @@ class GenericComputePollster(plugin_base.PollsterBase):
 
     def setup_environment(self):
         super(GenericComputePollster, self).setup_environment()
-        self.inspector = self._get_inspector(self.conf)
+        self.inspector = GenericComputePollster._get_inspector(self.conf)
 
     @staticmethod
     def aggregate_method(stats):
         # Don't aggregate anything by default
         return stats
 
-    @classmethod
-    def _get_inspector(cls, conf):
+    @staticmethod
+    def _get_inspector(conf):
         # FIXME(sileht): This doesn't looks threadsafe...
         try:
-            inspector = cls._inspector
+            inspector = GenericComputePollster._inspector
         except AttributeError:
             inspector = virt_inspector.get_hypervisor_inspector(conf)
-            cls._inspector = inspector
+            GenericComputePollster._inspector = inspector
         return inspector
 
     @property
@@ -94,7 +99,7 @@ class GenericComputePollster(plugin_base.PollsterBase):
         if instance.id not in cache[self.inspector_method]:
             result = getattr(self.inspector, self.inspector_method)(
                 instance, duration)
-            polled_time = monotonic.monotonic()
+            polled_time = now()
             # Ensure we don't cache an iterator
             if isinstance(result, collections.Iterable):
                 result = list(result)
@@ -158,6 +163,7 @@ class GenericComputePollster(plugin_base.PollsterBase):
                             '%(instance_id)s, non-fatal reason: %(exc)s',
                             {'pollster': self.__class__.__name__,
                              'instance_id': instance.id, 'exc': e})
+                raise plugin_base.PollsterPermanentError(resources)
             except ceilometer.NotImplementedError:
                 # Selected inspector does not implement this pollster.
                 LOG.debug('%(inspector)s does not provide data for '
