@@ -20,9 +20,9 @@ from oslotest import base
 import six
 
 from ceilometer.ipmi.platform import intel_node_manager as node_manager
+from ceilometer.privsep import ipmitool
 from ceilometer import service
 from ceilometer.tests.unit.ipmi.platform import fake_utils
-from ceilometer import utils
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -56,7 +56,7 @@ class _Base(base.BaseTestCase):
 class TestNodeManagerV3(_Base):
 
     def init_test_engine(self):
-        utils.execute = mock.Mock(side_effect=fake_utils.execute_with_nm_v3)
+        ipmitool.ipmi = mock.Mock(side_effect=fake_utils.execute_with_nm_v3)
 
     def test_read_airflow(self):
         airflow = self.nm.read_airflow()
@@ -110,7 +110,7 @@ class TestNodeManagerV3(_Base):
 class TestNodeManager(_Base):
 
     def init_test_engine(self):
-        utils.execute = mock.Mock(side_effect=fake_utils.execute_with_nm_v2)
+        ipmitool.ipmi = mock.Mock(side_effect=fake_utils.execute_with_nm_v2)
 
     def test_read_power_all(self):
         power = self.nm.read_power_all()
@@ -162,7 +162,7 @@ class TestNodeManager(_Base):
 class TestNonNodeManager(_Base):
 
     def init_test_engine(self):
-        utils.execute = mock.Mock(side_effect=fake_utils.execute_without_nm)
+        ipmitool.ipmi = mock.Mock(side_effect=fake_utils.execute_without_nm)
 
     def test_read_power_all(self):
         # no NM support
